"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ByteMatchSetFieldToMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    data: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        data: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___ByteMatchSetFieldToMatch = ByteMatchSetFieldToMatch

@typing_extensions.final
class ByteMatchSetByteMatchTuple(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FIELD_TO_MATCH_FIELD_NUMBER: builtins.int
    POSITIONAL_CONSTRAINT_FIELD_NUMBER: builtins.int
    TARGET_STRING_FIELD_NUMBER: builtins.int
    TARGET_STRING_BASE64_FIELD_NUMBER: builtins.int
    TEXT_TRANSFORMATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def field_to_match(self) -> global___ByteMatchSetFieldToMatch: ...
    positional_constraint: builtins.str
    target_string: builtins.str
    target_string_base64: builtins.str
    text_transformation: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        field_to_match: global___ByteMatchSetFieldToMatch | None = ...,
        positional_constraint: builtins.str = ...,
        target_string: builtins.str = ...,
        target_string_base64: builtins.str = ...,
        text_transformation: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["field_to_match", b"field_to_match", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_to_match", b"field_to_match", "positional_constraint", b"positional_constraint", "resource_info", b"resource_info", "target_string", b"target_string", "target_string_base64", b"target_string_base64", "text_transformation", b"text_transformation"]) -> None: ...

global___ByteMatchSetByteMatchTuple = ByteMatchSetByteMatchTuple

@typing_extensions.final
class ByteMatchSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BYTE_MATCH_TUPLES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def byte_match_tuples(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ByteMatchSetByteMatchTuple]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        byte_match_tuples: collections.abc.Iterable[global___ByteMatchSetByteMatchTuple] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["byte_match_tuples", b"byte_match_tuples", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ByteMatchSet = ByteMatchSet

@typing_extensions.final
class WAF(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BYTE_MATCH_SET_FIELD_NUMBER: builtins.int
    IP_SET_FIELD_NUMBER: builtins.int
    RULE_FIELD_NUMBER: builtins.int
    SIZE_CONSTRAINT_SET_FIELD_NUMBER: builtins.int
    SQL_INJECTION_MATCH_SET_FIELD_NUMBER: builtins.int
    WEB_A_C_L_FIELD_NUMBER: builtins.int
    XSS_MATCH_SET_FIELD_NUMBER: builtins.int
    @property
    def byte_match_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ByteMatchSet]: ...
    @property
    def ip_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IPSet]: ...
    @property
    def rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Rule]: ...
    @property
    def size_constraint_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SizeConstraintSet]: ...
    @property
    def sql_injection_match_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SqlInjectionMatchSet]: ...
    @property
    def web_a_c_l(self) -> global___WebACL: ...
    @property
    def xss_match_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___XssMatchSet]: ...
    def __init__(
        self,
        *,
        byte_match_set: collections.abc.Iterable[global___ByteMatchSet] | None = ...,
        ip_set: collections.abc.Iterable[global___IPSet] | None = ...,
        rule: collections.abc.Iterable[global___Rule] | None = ...,
        size_constraint_set: collections.abc.Iterable[global___SizeConstraintSet] | None = ...,
        sql_injection_match_set: collections.abc.Iterable[global___SqlInjectionMatchSet] | None = ...,
        web_a_c_l: global___WebACL | None = ...,
        xss_match_set: collections.abc.Iterable[global___XssMatchSet] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["web_a_c_l", b"web_a_c_l"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["byte_match_set", b"byte_match_set", "ip_set", b"ip_set", "rule", b"rule", "size_constraint_set", b"size_constraint_set", "sql_injection_match_set", b"sql_injection_match_set", "web_a_c_l", b"web_a_c_l", "xss_match_set", b"xss_match_set"]) -> None: ...

global___WAF = WAF

@typing_extensions.final
class IPSetIPSetDescriptor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___IPSetIPSetDescriptor = IPSetIPSetDescriptor

@typing_extensions.final
class IPSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IP_SET_DESCRIPTORS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def ip_set_descriptors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IPSetIPSetDescriptor]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ip_set_descriptors: collections.abc.Iterable[global___IPSetIPSetDescriptor] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_set_descriptors", b"ip_set_descriptors", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___IPSet = IPSet

@typing_extensions.final
class RulePredicate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATA_ID_FIELD_NUMBER: builtins.int
    NEGATED_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    data_id: builtins.str
    negated: builtins.bool
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        data_id: builtins.str = ...,
        negated: builtins.bool = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_id", b"data_id", "negated", b"negated", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___RulePredicate = RulePredicate

@typing_extensions.final
class Rule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PREDICATES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    metric_name: builtins.str
    name: builtins.str
    @property
    def predicates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RulePredicate]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        metric_name: builtins.str = ...,
        name: builtins.str = ...,
        predicates: collections.abc.Iterable[global___RulePredicate] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metric_name", b"metric_name", "name", b"name", "predicates", b"predicates", "resource_info", b"resource_info"]) -> None: ...

global___Rule = Rule

@typing_extensions.final
class SizeConstraintSetFieldToMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    data: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        data: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "resource_info", b"resource_info"]) -> None: ...

global___SizeConstraintSetFieldToMatch = SizeConstraintSetFieldToMatch

@typing_extensions.final
class SizeConstraintSetSizeConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPARISON_OPERATOR_FIELD_NUMBER: builtins.int
    FIELD_TO_MATCH_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TEXT_TRANSFORMATION_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    comparison_operator: builtins.str
    @property
    def field_to_match(self) -> global___SizeConstraintSetFieldToMatch: ...
    size: builtins.int
    text_transformation: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        comparison_operator: builtins.str = ...,
        field_to_match: global___SizeConstraintSetFieldToMatch | None = ...,
        size: builtins.int = ...,
        text_transformation: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["field_to_match", b"field_to_match", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comparison_operator", b"comparison_operator", "field_to_match", b"field_to_match", "resource_info", b"resource_info", "size", b"size", "text_transformation", b"text_transformation", "type", b"type"]) -> None: ...

global___SizeConstraintSetSizeConstraint = SizeConstraintSetSizeConstraint

@typing_extensions.final
class SizeConstraintSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_CONSTRAINTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def size_constraints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SizeConstraintSetSizeConstraint]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        size_constraints: collections.abc.Iterable[global___SizeConstraintSetSizeConstraint] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "size_constraints", b"size_constraints"]) -> None: ...

global___SizeConstraintSet = SizeConstraintSet

@typing_extensions.final
class SqlInjectionMatchSetFieldToMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    data: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        data: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___SqlInjectionMatchSetFieldToMatch = SqlInjectionMatchSetFieldToMatch

@typing_extensions.final
class SqlInjectionMatchSetSqlInjectionMatchTuple(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FIELD_TO_MATCH_FIELD_NUMBER: builtins.int
    TEXT_TRANSFORMATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def field_to_match(self) -> global___SqlInjectionMatchSetFieldToMatch: ...
    text_transformation: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        field_to_match: global___SqlInjectionMatchSetFieldToMatch | None = ...,
        text_transformation: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["field_to_match", b"field_to_match", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_to_match", b"field_to_match", "resource_info", b"resource_info", "text_transformation", b"text_transformation"]) -> None: ...

global___SqlInjectionMatchSetSqlInjectionMatchTuple = SqlInjectionMatchSetSqlInjectionMatchTuple

@typing_extensions.final
class SqlInjectionMatchSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SQL_INJECTION_MATCH_TUPLES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def sql_injection_match_tuples(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SqlInjectionMatchSetSqlInjectionMatchTuple]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        sql_injection_match_tuples: collections.abc.Iterable[global___SqlInjectionMatchSetSqlInjectionMatchTuple] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "sql_injection_match_tuples", b"sql_injection_match_tuples"]) -> None: ...

global___SqlInjectionMatchSet = SqlInjectionMatchSet

@typing_extensions.final
class WebACLWafAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___WebACLWafAction = WebACLWafAction

@typing_extensions.final
class WebACLActivatedRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    RULE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def action(self) -> global___WebACLWafAction: ...
    priority: builtins.int
    rule_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        action: global___WebACLWafAction | None = ...,
        priority: builtins.int = ...,
        rule_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "priority", b"priority", "resource_info", b"resource_info", "rule_id", b"rule_id"]) -> None: ...

global___WebACLActivatedRule = WebACLActivatedRule

@typing_extensions.final
class WebACL(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEFAULT_ACTION_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def default_action(self) -> global___WebACLWafAction: ...
    metric_name: builtins.str
    name: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WebACLActivatedRule]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        default_action: global___WebACLWafAction | None = ...,
        metric_name: builtins.str = ...,
        name: builtins.str = ...,
        rules: collections.abc.Iterable[global___WebACLActivatedRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_action", b"default_action", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_action", b"default_action", "metric_name", b"metric_name", "name", b"name", "resource_info", b"resource_info", "rules", b"rules"]) -> None: ...

global___WebACL = WebACL

@typing_extensions.final
class XssMatchSetFieldToMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    data: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        data: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "resource_info", b"resource_info"]) -> None: ...

global___XssMatchSetFieldToMatch = XssMatchSetFieldToMatch

@typing_extensions.final
class XssMatchSetXssMatchTuple(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FIELD_TO_MATCH_FIELD_NUMBER: builtins.int
    TEXT_TRANSFORMATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def field_to_match(self) -> global___XssMatchSetFieldToMatch: ...
    text_transformation: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        field_to_match: global___XssMatchSetFieldToMatch | None = ...,
        text_transformation: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["field_to_match", b"field_to_match", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["field_to_match", b"field_to_match", "resource_info", b"resource_info", "text_transformation", b"text_transformation"]) -> None: ...

global___XssMatchSetXssMatchTuple = XssMatchSetXssMatchTuple

@typing_extensions.final
class XssMatchSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    XSS_MATCH_TUPLES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def xss_match_tuples(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___XssMatchSetXssMatchTuple]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        xss_match_tuples: collections.abc.Iterable[global___XssMatchSetXssMatchTuple] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "xss_match_tuples", b"xss_match_tuples"]) -> None: ...

global___XssMatchSet = XssMatchSet



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_kms_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_kms_pb2 as gcp_dot_gcp__kms__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgcp/gcp_google_kms_bundle.proto\x12!oak9.tython.gcp.google_kms_bundle\x1a\x13shared/shared.proto\x1a\x11gcp/gcp_kms.proto\"\xe3\x05\n\tGoogleKms\x12\x39\n\x0ekms_crypto_key\x18\x01 \x03(\x0b\x32!.oak9.tython.gcp.kms.KmsCryptoKey\x12O\n\x1akms_crypto_key_iam_binding\x18\x02 \x03(\x0b\x32+.oak9.tython.gcp.kms.KmsCryptoKeyIamBinding\x12M\n\x19kms_crypto_key_iam_member\x18\x03 \x03(\x0b\x32*.oak9.tython.gcp.kms.KmsCryptoKeyIamMember\x12M\n\x19kms_crypto_key_iam_policy\x18\x04 \x03(\x0b\x32*.oak9.tython.gcp.kms.KmsCryptoKeyIamPolicy\x12\x35\n\x0ckms_key_ring\x18\x05 \x01(\x0b\x32\x1f.oak9.tython.gcp.kms.KmsKeyRing\x12K\n\x18kms_key_ring_iam_binding\x18\x06 \x03(\x0b\x32).oak9.tython.gcp.kms.KmsKeyRingIamBinding\x12I\n\x17kms_key_ring_iam_member\x18\x07 \x03(\x0b\x32(.oak9.tython.gcp.kms.KmsKeyRingIamMember\x12I\n\x17kms_key_ring_iam_policy\x18\x08 \x03(\x0b\x32(.oak9.tython.gcp.kms.KmsKeyRingIamPolicy\x12I\n\x17kms_key_ring_import_job\x18\t \x03(\x0b\x32(.oak9.tython.gcp.kms.KmsKeyRingImportJob\x12G\n\x15kms_secret_ciphertext\x18\n \x01(\x0b\x32(.oak9.tython.gcp.kms.KmsSecretCiphertextb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_kms_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLEKMS._serialized_start=111
  _GOOGLEKMS._serialized_end=850
# @@protoc_insertion_point(module_scope)



import os
import sys
from typing import Protocol, runtime_checkable, Set, Optional, List
from colorama import Fore, Style, init
from core.services.runner_input_service import RunnerInputService

from core.bp_metadata_utils.customer_blueprint_repo import CustomerBlueprintRepo
from core.bp_metadata_utils.python_source_file_utils import get_blueprint_classes
from core.types import Blueprint, Finding

BLUEPRINT_DIR = ''
CURRENT_DIR = os.path.dirname(os.path.realpath(__file__))
REPO_DIR = '/'

@runtime_checkable
class SupportsValidation(Protocol):
    def validate(self) -> Set[Finding]:
        """
        Entry point into component's validation logic
        """


class Runner:

    @staticmethod
    def run(validation_target: SupportsValidation):
        return validation_target.validate()


def main(argv):
    print(f"{Fore.LIGHTRED_EX}************************************************************************")
    print(f"    Running oak9's Python Framework                        ")
    print(f"************************************************************************{Style.RESET_ALL}")


    try:
        init(convert=True) # Ensure that colorama works on Windows

        path = None
        # TODO: pass arguments here from CLI for specific CLI commands
        if len(argv) > 0:
            path = argv[0]

        #TODO: get project_id as argument
        project_id = "proj-cbalbin0625cce06-48"
        
        runner = Runner()

        if path:
            blueprint_dir = path
        else:
            # TODO: We could default to /blueprints here
            raise Exception("Blueprints directory was not provided.")

        findings = set()

        blueprint_repo = CustomerBlueprintRepo(path)

        # TODO: make this conditional on a CLI command
        blueprint_repo.print_blueprint_summary()

        # Fetch runner input data
        runner_input = RunnerInputService.fetch_runner_input(project_id)

        # TODO: initialize blueprint properly
        '''
        Run all blueprints
        '''
        print(f"{Fore.LIGHTBLACK_EX}************************************************************************\n"
              f"    {Fore.BLUE}Running Blueprints{Style.RESET_ALL}\n"
              f"{Fore.LIGHTBLACK_EX}************************************************************************{Style.RESET_ALL}")

        # get all blueprint classes
        # TODO: filter out import of base Blueprint class
        blueprint_classes = []
        for path in blueprint_repo.blueprint_file_paths:
            blueprint_classes.extend(get_blueprint_classes(path))

        # Run each blueprint
        for blueprint in blueprint_classes:
            customer_blueprint = blueprint[1](graph=runner_input.graph)
            # TODO: check usage guidelines to see if findings should be reported
            bp_findings = runner.run(customer_blueprint)
            print(f"[✓] Successfully ran checks in {blueprint[0]}")
            if bp_findings:
                findings.update(bp_findings)

        # TODO: send gaps to validation broker for the apply command
        print(f"\n{Fore.LIGHTBLACK_EX}************************************************************************\n"
              f"    {Fore.BLUE}Found {Style.BRIGHT}{len(findings)}{Style.NORMAL} Findings{Style.RESET_ALL}\n"
              f"{Fore.LIGHTBLACK_EX}************************************************************************{Style.RESET_ALL}")
        for finding in findings:
            print(finding)
        sys.exit(0)

    except Exception as e:
        print("Raised Exception: " + str(e))
        sys.exit(1)


if __package__ == "":
    # Resulting path is the name of the wheel itself
    path = os.path.dirname(__file__)
    sys.path.insert(0, path)

if __name__ == "__main__":
    import sys
    main(sys.argv[1:])



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_cloud9.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ws/aws_cloud9.proto\x12\x16oak9.tython.aws.cloud9\x1a\x13shared/shared.proto\"\x83\x01\n\x18\x45nvironmentEC2Repository\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0epath_component\x18\x02 \x01(\t\x12\x16\n\x0erepository_url\x18\x03 \x01(\t\"\x9c\x03\n\x0e\x45nvironmentEC2\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x46\n\x0crepositories\x18\x02 \x03(\x0b\x32\x30.oak9.tython.aws.cloud9.EnvironmentEC2Repository\x12\x11\n\towner_arn\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x05 \x01(\t\x12#\n\x1b\x61utomatic_stop_time_minutes\x18\x06 \x01(\x05\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12\x15\n\rinstance_type\x18\x08 \x01(\t\x12>\n\x04tags\x18\t \x03(\x0b\x32\x30.oak9.tython.aws.cloud9.EnvironmentEC2.TagsEntry\x12\x0c\n\x04name\x18\n \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"J\n\x06\x43loud9\x12@\n\x10\x65nvironment_e_c2\x18\x01 \x03(\x0b\x32&.oak9.tython.aws.cloud9.EnvironmentEC2b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_cloud9_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENVIRONMENTEC2_TAGSENTRY._options = None
  _ENVIRONMENTEC2_TAGSENTRY._serialized_options = b'8\001'
  _ENVIRONMENTEC2REPOSITORY._serialized_start=70
  _ENVIRONMENTEC2REPOSITORY._serialized_end=201
  _ENVIRONMENTEC2._serialized_start=204
  _ENVIRONMENTEC2._serialized_end=616
  _ENVIRONMENTEC2_TAGSENTRY._serialized_start=573
  _ENVIRONMENTEC2_TAGSENTRY._serialized_end=616
  _CLOUD9._serialized_start=618
  _CLOUD9._serialized_end=692
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Destination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_NAME_FIELD_NUMBER: builtins.int
    DESTINATION_POLICY_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    TARGET_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    destination_name: builtins.str
    destination_policy: builtins.str
    role_arn: builtins.str
    target_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination_name: builtins.str = ...,
        destination_policy: builtins.str = ...,
        role_arn: builtins.str = ...,
        target_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_name", b"destination_name", "destination_policy", b"destination_policy", "resource_info", b"resource_info", "role_arn", b"role_arn", "target_arn", b"target_arn"]) -> None: ...

global___Destination = Destination

@typing_extensions.final
class Logs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESTINATION_FIELD_NUMBER: builtins.int
    LOG_GROUP_FIELD_NUMBER: builtins.int
    LOG_STREAM_FIELD_NUMBER: builtins.int
    METRIC_FILTER_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_FILTER_FIELD_NUMBER: builtins.int
    @property
    def destination(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Destination]: ...
    @property
    def log_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogGroup]: ...
    @property
    def log_stream(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LogStream]: ...
    @property
    def metric_filter(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetricFilter]: ...
    @property
    def subscription_filter(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubscriptionFilter]: ...
    def __init__(
        self,
        *,
        destination: collections.abc.Iterable[global___Destination] | None = ...,
        log_group: collections.abc.Iterable[global___LogGroup] | None = ...,
        log_stream: collections.abc.Iterable[global___LogStream] | None = ...,
        metric_filter: collections.abc.Iterable[global___MetricFilter] | None = ...,
        subscription_filter: collections.abc.Iterable[global___SubscriptionFilter] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination", b"destination", "log_group", b"log_group", "log_stream", b"log_stream", "metric_filter", b"metric_filter", "subscription_filter", b"subscription_filter"]) -> None: ...

global___Logs = Logs

@typing_extensions.final
class LogGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    RETENTION_IN_DAYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    log_group_name: builtins.str
    retention_in_days: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        log_group_name: builtins.str = ...,
        retention_in_days: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["log_group_name", b"log_group_name", "resource_info", b"resource_info", "retention_in_days", b"retention_in_days"]) -> None: ...

global___LogGroup = LogGroup

@typing_extensions.final
class LogStream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    LOG_STREAM_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    log_group_name: builtins.str
    log_stream_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        log_group_name: builtins.str = ...,
        log_stream_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["log_group_name", b"log_group_name", "log_stream_name", b"log_stream_name", "resource_info", b"resource_info"]) -> None: ...

global___LogStream = LogStream

@typing_extensions.final
class MetricFilterMetricTransformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    METRIC_NAME_FIELD_NUMBER: builtins.int
    METRIC_NAMESPACE_FIELD_NUMBER: builtins.int
    METRIC_VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    default_value: builtins.float
    metric_name: builtins.str
    metric_namespace: builtins.str
    metric_value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        default_value: builtins.float = ...,
        metric_name: builtins.str = ...,
        metric_namespace: builtins.str = ...,
        metric_value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "metric_name", b"metric_name", "metric_namespace", b"metric_namespace", "metric_value", b"metric_value", "resource_info", b"resource_info"]) -> None: ...

global___MetricFilterMetricTransformation = MetricFilterMetricTransformation

@typing_extensions.final
class MetricFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FILTER_PATTERN_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    METRIC_TRANSFORMATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    filter_pattern: builtins.str
    log_group_name: builtins.str
    @property
    def metric_transformations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetricFilterMetricTransformation]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        filter_pattern: builtins.str = ...,
        log_group_name: builtins.str = ...,
        metric_transformations: collections.abc.Iterable[global___MetricFilterMetricTransformation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter_pattern", b"filter_pattern", "log_group_name", b"log_group_name", "metric_transformations", b"metric_transformations", "resource_info", b"resource_info"]) -> None: ...

global___MetricFilter = MetricFilter

@typing_extensions.final
class SubscriptionFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_ARN_FIELD_NUMBER: builtins.int
    FILTER_PATTERN_FIELD_NUMBER: builtins.int
    LOG_GROUP_NAME_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    destination_arn: builtins.str
    filter_pattern: builtins.str
    log_group_name: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination_arn: builtins.str = ...,
        filter_pattern: builtins.str = ...,
        log_group_name: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_arn", b"destination_arn", "filter_pattern", b"filter_pattern", "log_group_name", b"log_group_name", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___SubscriptionFilter = SubscriptionFilter



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Eviction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    DELETE_OPTIONS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def delete_options(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.DeleteOptions: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        delete_options: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.DeleteOptions | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delete_options", b"delete_options", "metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "delete_options", b"delete_options", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___Eviction = Eviction

@typing_extensions.final
class PodDisruptionBudget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___PodDisruptionBudgetSpec: ...
    @property
    def status(self) -> global___PodDisruptionBudgetStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___PodDisruptionBudgetSpec | None = ...,
        status: global___PodDisruptionBudgetStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___PodDisruptionBudget = PodDisruptionBudget

@typing_extensions.final
class PodDisruptionBudgetList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodDisruptionBudget]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___PodDisruptionBudget] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___PodDisruptionBudgetList = PodDisruptionBudgetList

@typing_extensions.final
class PodDisruptionBudgetSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_UNAVAILABLE_FIELD_NUMBER: builtins.int
    MIN_AVAILABLE_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    UNHEALTHY_POD_EVICTION_POLICY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def max_unavailable(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    @property
    def min_available(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    @property
    def selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    unhealthy_pod_eviction_policy: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        max_unavailable: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        min_available: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        unhealthy_pod_eviction_policy: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_unavailable", b"max_unavailable", "min_available", b"min_available", "resource_info", b"resource_info", "selector", b"selector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_unavailable", b"max_unavailable", "min_available", b"min_available", "resource_info", b"resource_info", "selector", b"selector", "unhealthy_pod_eviction_policy", b"unhealthy_pod_eviction_policy"]) -> None: ...

global___PodDisruptionBudgetSpec = PodDisruptionBudgetSpec

@typing_extensions.final
class PodDisruptionBudgetStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DisruptedPodsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONDITIONS_FIELD_NUMBER: builtins.int
    CURRENT_HEALTHY_FIELD_NUMBER: builtins.int
    DESIRED_HEALTHY_FIELD_NUMBER: builtins.int
    DISRUPTED_PODS_FIELD_NUMBER: builtins.int
    DISRUPTIONS_ALLOWED_FIELD_NUMBER: builtins.int
    EXPECTED_PODS_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Condition]: ...
    current_healthy: builtins.int
    desired_healthy: builtins.int
    @property
    def disrupted_pods(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    disruptions_allowed: builtins.int
    expected_pods: builtins.int
    observed_generation: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        conditions: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Condition] | None = ...,
        current_healthy: builtins.int = ...,
        desired_healthy: builtins.int = ...,
        disrupted_pods: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        disruptions_allowed: builtins.int = ...,
        expected_pods: builtins.int = ...,
        observed_generation: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conditions", b"conditions", "current_healthy", b"current_healthy", "desired_healthy", b"desired_healthy", "disrupted_pods", b"disrupted_pods", "disruptions_allowed", b"disruptions_allowed", "expected_pods", b"expected_pods", "observed_generation", b"observed_generation", "resource_info", b"resource_info"]) -> None: ...

global___PodDisruptionBudgetStatus = PodDisruptionBudgetStatus



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_glue.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61ws/aws_glue.proto\x12\x14oak9.tython.aws.glue\x1a\x13shared/shared.proto\"\x89\x01\n\x17\x43lassifierXMLClassifier\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07row_tag\x18\x02 \x01(\t\x12\x16\n\x0e\x63lassification\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"t\n\x18\x43lassifierJsonClassifier\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tjson_path\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xef\x01\n\x17\x43lassifierCsvClassifier\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cquote_symbol\x18\x02 \x01(\t\x12\x17\n\x0f\x63ontains_header\x18\x03 \x01(\t\x12\x11\n\tdelimiter\x18\x04 \x01(\t\x12\x0e\n\x06header\x18\x05 \x03(\t\x12\x1b\n\x13\x61llow_single_column\x18\x06 \x01(\x08\x12\x1e\n\x16\x64isable_value_trimming\x18\x07 \x01(\x08\x12\x0c\n\x04name\x18\x08 \x01(\t\"\xa8\x01\n\x18\x43lassifierGrokClassifier\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63ustom_patterns\x18\x02 \x01(\t\x12\x14\n\x0cgrok_pattern\x18\x03 \x01(\t\x12\x16\n\x0e\x63lassification\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\"\xe5\x02\n\nClassifier\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x45\n\x0exml_classifier\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.glue.ClassifierXMLClassifier\x12G\n\x0fjson_classifier\x18\x03 \x01(\x0b\x32..oak9.tython.aws.glue.ClassifierJsonClassifier\x12\x45\n\x0e\x63sv_classifier\x18\x04 \x01(\x0b\x32-.oak9.tython.aws.glue.ClassifierCsvClassifier\x12G\n\x0fgrok_classifier\x18\x05 \x01(\x0b\x32..oak9.tython.aws.glue.ClassifierGrokClassifier\"\xc3\x06\n\x04Glue\x12\x34\n\nclassifier\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.glue.Classifier\x12\x34\n\nconnection\x18\x02 \x03(\x0b\x32 .oak9.tython.aws.glue.Connection\x12.\n\x07\x63rawler\x18\x03 \x03(\x0b\x32\x1d.oak9.tython.aws.glue.Crawler\x12]\n data_catalog_encryption_settings\x18\x04 \x03(\x0b\x32\x33.oak9.tython.aws.glue.DataCatalogEncryptionSettings\x12\x30\n\x08\x64\x61tabase\x18\x05 \x03(\x0b\x32\x1e.oak9.tython.aws.glue.Database\x12\x37\n\x0c\x64\x65v_endpoint\x18\x06 \x03(\x0b\x32!.oak9.tython.aws.glue.DevEndpoint\x12&\n\x03job\x18\x07 \x03(\x0b\x32\x19.oak9.tython.aws.glue.Job\x12\x37\n\x0cml_transform\x18\x08 \x03(\x0b\x32!.oak9.tython.aws.glue.MLTransform\x12\x32\n\tpartition\x18\t \x03(\x0b\x32\x1f.oak9.tython.aws.glue.Partition\x12K\n\x16security_configuration\x18\n \x03(\x0b\x32+.oak9.tython.aws.glue.SecurityConfiguration\x12*\n\x05table\x18\x0b \x03(\x0b\x32\x1b.oak9.tython.aws.glue.Table\x12.\n\x07trigger\x18\x0c \x03(\x0b\x32\x1d.oak9.tython.aws.glue.Trigger\x12\x30\n\x08workflow\x18\r \x03(\x0b\x32\x1e.oak9.tython.aws.glue.Workflow\x12\x65\n$security_configuration_s3_encryption\x18\x0e \x03(\x0b\x32\x37.oak9.tython.aws.glue.SecurityConfigurationS3Encryption\"\xb1\x01\n(ConnectionPhysicalConnectionRequirements\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61vailability_zone\x18\x02 \x01(\t\x12\x1e\n\x16security_group_id_list\x18\x03 \x03(\t\x12\x11\n\tsubnet_id\x18\x04 \x01(\t\"\xb9\x03\n\x19\x43onnectionConnectionInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x03 \x01(\t\x12\x16\n\x0ematch_criteria\x18\x04 \x03(\t\x12h\n physical_connection_requirements\x18\x05 \x01(\x0b\x32>.oak9.tython.aws.glue.ConnectionPhysicalConnectionRequirements\x12h\n\x15\x63onnection_properties\x18\x06 \x03(\x0b\x32I.oak9.tython.aws.glue.ConnectionConnectionInput.ConnectionPropertiesEntry\x12\x0c\n\x04name\x18\x07 \x01(\t\x1a;\n\x19\x43onnectionPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\nConnection\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12I\n\x10\x63onnection_input\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.glue.ConnectionConnectionInput\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\"\x86\x01\n\x19\x43rawlerSchemaChangePolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fupdate_behavior\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65lete_behavior\x18\x03 \x01(\t\"g\n\x0f\x43rawlerSchedule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13schedule_expression\x18\x02 \x01(\t\"l\n\x0f\x43rawlerS3Target\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x12\n\nexclusions\x18\x03 \x03(\t\"v\n\x14\x43rawlerCatalogTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\x12\x0e\n\x06tables\x18\x03 \x03(\t\"\x87\x01\n\x11\x43rawlerJdbcTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63onnection_name\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x12\n\nexclusions\x18\x04 \x03(\t\"^\n\x15\x43rawlerDynamoDBTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04path\x18\x02 \x01(\t\"\xd0\x02\n\x0e\x43rawlerTargets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x39\n\ns3_targets\x18\x02 \x03(\x0b\x32%.oak9.tython.aws.glue.CrawlerS3Target\x12\x43\n\x0f\x63\x61talog_targets\x18\x03 \x03(\x0b\x32*.oak9.tython.aws.glue.CrawlerCatalogTarget\x12=\n\x0cjdbc_targets\x18\x04 \x03(\x0b\x32\'.oak9.tython.aws.glue.CrawlerJdbcTarget\x12\x46\n\x11\x64ynamo_db_targets\x18\x05 \x03(\x0b\x32+.oak9.tython.aws.glue.CrawlerDynamoDBTarget\"\x97\x04\n\x07\x43rawler\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x13\n\x0b\x63lassifiers\x18\x03 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12M\n\x14schema_change_policy\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.glue.CrawlerSchemaChangePolicy\x12\x15\n\rconfiguration\x18\x06 \x01(\t\x12\x37\n\x08schedule\x18\x07 \x01(\x0b\x32%.oak9.tython.aws.glue.CrawlerSchedule\x12\x15\n\rdatabase_name\x18\x08 \x01(\t\x12\x35\n\x07targets\x18\t \x01(\x0b\x32$.oak9.tython.aws.glue.CrawlerTargets\x12&\n\x1e\x63rawler_security_configuration\x18\n \x01(\t\x12\x14\n\x0ctable_prefix\x18\x0b \x01(\t\x12\x35\n\x04tags\x18\x0c \x03(\x0b\x32\'.oak9.tython.aws.glue.Crawler.TagsEntry\x12\x0c\n\x04name\x18\r \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x01\n9DataCatalogEncryptionSettingsConnectionPasswordEncryption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12,\n$return_connection_password_encrypted\x18\x02 \x01(\x08\x12\x12\n\nkms_key_id\x18\x03 \x01(\t\"\xa5\x01\n-DataCatalogEncryptionSettingsEncryptionAtRest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x63\x61talog_encryption_mode\x18\x02 \x01(\t\x12\x1a\n\x12sse_aws_kms_key_id\x18\x03 \x01(\t\"\xcf\x02\n:DataCatalogEncryptionSettingsDataCatalogEncryptionSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12w\n\x1e\x63onnection_password_encryption\x18\x02 \x01(\x0b\x32O.oak9.tython.aws.glue.DataCatalogEncryptionSettingsConnectionPasswordEncryption\x12_\n\x12\x65ncryption_at_rest\x18\x03 \x01(\x0b\x32\x43.oak9.tython.aws.glue.DataCatalogEncryptionSettingsEncryptionAtRest\"\xe8\x01\n\x1d\x44\x61taCatalogEncryptionSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12z\n data_catalog_encryption_settings\x18\x02 \x01(\x0b\x32P.oak9.tython.aws.glue.DataCatalogEncryptionSettingsDataCatalogEncryptionSettings\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\"\x8d\x02\n\x15\x44\x61tabaseDatabaseInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0clocation_uri\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12O\n\nparameters\x18\x04 \x03(\x0b\x32;.oak9.tython.aws.glue.DatabaseDatabaseInput.ParametersEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x01\n\x08\x44\x61tabase\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\x0e\x64\x61tabase_input\x18\x02 \x01(\x0b\x32+.oak9.tython.aws.glue.DatabaseDatabaseInput\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\"\xe4\x04\n\x0b\x44\x65vEndpoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12\x65xtra_jars_s3_path\x18\x02 \x01(\t\x12\x12\n\npublic_key\x18\x03 \x01(\t\x12\x17\n\x0fnumber_of_nodes\x18\x04 \x01(\x05\x12\x43\n\targuments\x18\x05 \x03(\x0b\x32\x30.oak9.tython.aws.glue.DevEndpoint.ArgumentsEntry\x12\x11\n\tsubnet_id\x18\x06 \x01(\t\x12\x13\n\x0bpublic_keys\x18\x07 \x03(\t\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12\x10\n\x08role_arn\x18\t \x01(\t\x12\x13\n\x0bworker_type\x18\n \x01(\t\x12\x15\n\rendpoint_name\x18\x0b \x01(\t\x12\x14\n\x0cglue_version\x18\x0c \x01(\t\x12!\n\x19\x65xtra_python_libs_s3_path\x18\r \x01(\t\x12\x1e\n\x16security_configuration\x18\x0e \x01(\t\x12\x19\n\x11number_of_workers\x18\x0f \x01(\x05\x12\x39\n\x04tags\x18\x10 \x03(\x0b\x32+.oak9.tython.aws.glue.DevEndpoint.TagsEntry\x1a\x30\n\x0e\x41rgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n\x12JobConnectionsList\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63onnections\x18\x02 \x03(\t\"n\n\x17JobNotificationProperty\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12notify_delay_after\x18\x02 \x01(\x05\"\x87\x01\n\rJobJobCommand\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0epython_version\x18\x02 \x01(\t\x12\x17\n\x0fscript_location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"l\n\x14JobExecutionProperty\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13max_concurrent_runs\x18\x02 \x01(\x01\"\xae\x06\n\x03Job\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12=\n\x0b\x63onnections\x18\x02 \x01(\x0b\x32(.oak9.tython.aws.glue.JobConnectionsList\x12\x13\n\x0bmax_retries\x18\x03 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0f\n\x07timeout\x18\x05 \x01(\x05\x12\x1a\n\x12\x61llocated_capacity\x18\x06 \x01(\x01\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0c\n\x04role\x18\x08 \x01(\t\x12J\n\x11\x64\x65\x66\x61ult_arguments\x18\t \x03(\x0b\x32/.oak9.tython.aws.glue.Job.DefaultArgumentsEntry\x12L\n\x15notification_property\x18\n \x01(\x0b\x32-.oak9.tython.aws.glue.JobNotificationProperty\x12\x13\n\x0bworker_type\x18\x0b \x01(\t\x12\x0f\n\x07log_uri\x18\x0c \x01(\t\x12\x34\n\x07\x63ommand\x18\r \x01(\x0b\x32#.oak9.tython.aws.glue.JobJobCommand\x12\x14\n\x0cglue_version\x18\x0e \x01(\t\x12\x46\n\x12\x65xecution_property\x18\x0f \x01(\x0b\x32*.oak9.tython.aws.glue.JobExecutionProperty\x12\x1e\n\x16security_configuration\x18\x10 \x01(\t\x12\x19\n\x11number_of_workers\x18\x11 \x01(\x05\x12\x31\n\x04tags\x18\x12 \x03(\x0b\x32#.oak9.tython.aws.glue.Job.TagsEntry\x12\x14\n\x0cmax_capacity\x18\x13 \x01(\x01\x1a\x37\n\x15\x44\x65\x66\x61ultArgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe0\x01\n MLTransformFindMatchesParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19precision_recall_tradeoff\x18\x02 \x01(\x01\x12\x1f\n\x17\x65nforce_provided_labels\x18\x03 \x01(\x08\x12\x1f\n\x17primary_key_column_name\x18\x04 \x01(\t\x12\x1e\n\x16\x61\x63\x63uracy_cost_tradeoff\x18\x05 \x01(\x01\"\xca\x01\n\x1eMLTransformTransformParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0etransform_type\x18\x02 \x01(\t\x12W\n\x17\x66ind_matches_parameters\x18\x03 \x01(\x0b\x32\x36.oak9.tython.aws.glue.MLTransformFindMatchesParameters\"\xa8\x01\n\x15MLTransformGlueTables\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x63onnection_name\x18\x02 \x01(\t\x12\x12\n\ntable_name\x18\x03 \x01(\t\x12\x15\n\rdatabase_name\x18\x04 \x01(\t\x12\x12\n\ncatalog_id\x18\x05 \x01(\t\"\x99\x01\n\x1cMLTransformInputRecordTables\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\x0bglue_tables\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.glue.MLTransformGlueTables\"\x86\x04\n\x0bMLTransform\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x13\n\x0bmax_retries\x18\x03 \x01(\x05\x12\x13\n\x0bworker_type\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0f\n\x07timeout\x18\x06 \x01(\x05\x12\x14\n\x0cglue_version\x18\x07 \x01(\t\x12R\n\x14transform_parameters\x18\x08 \x01(\x0b\x32\x34.oak9.tython.aws.glue.MLTransformTransformParameters\x12O\n\x13input_record_tables\x18\t \x01(\x0b\x32\x32.oak9.tython.aws.glue.MLTransformInputRecordTables\x12\x19\n\x11number_of_workers\x18\n \x01(\x05\x12\x39\n\x04tags\x18\x0b \x03(\x0b\x32+.oak9.tython.aws.glue.MLTransform.TagsEntry\x12\x0c\n\x04name\x18\x0c \x01(\t\x12\x14\n\x0cmax_capacity\x18\r \x01(\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc8\x02\n\x13PartitionSkewedInfo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13skewed_column_names\x18\x02 \x03(\t\x12\x1c\n\x14skewed_column_values\x18\x03 \x03(\t\x12w\n!skewed_column_value_location_maps\x18\x04 \x03(\x0b\x32L.oak9.tython.aws.glue.PartitionSkewedInfo.SkewedColumnValueLocationMapsEntry\x1a\x44\n\"SkewedColumnValueLocationMapsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"i\n\x0fPartitionColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xfb\x01\n\x12PartitionSerdeInfo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\nparameters\x18\x02 \x03(\x0b\x32\x38.oak9.tython.aws.glue.PartitionSerdeInfo.ParametersEntry\x12\x1d\n\x15serialization_library\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"m\n\x0ePartitionOrder\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\t\x12\x12\n\nsort_order\x18\x03 \x01(\x05\"\xf9\x04\n\x1aPartitionStorageDescriptor\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19stored_as_sub_directories\x18\x02 \x01(\x08\x12T\n\nparameters\x18\x03 \x03(\x0b\x32@.oak9.tython.aws.glue.PartitionStorageDescriptor.ParametersEntry\x12\x16\n\x0e\x62ucket_columns\x18\x04 \x03(\t\x12>\n\x0bskewed_info\x18\x05 \x01(\x0b\x32).oak9.tython.aws.glue.PartitionSkewedInfo\x12\x14\n\x0cinput_format\x18\x06 \x01(\t\x12\x19\n\x11number_of_buckets\x18\x07 \x01(\x05\x12\x15\n\routput_format\x18\x08 \x01(\t\x12\x36\n\x07\x63olumns\x18\t \x03(\x0b\x32%.oak9.tython.aws.glue.PartitionColumn\x12<\n\nserde_info\x18\n \x01(\x0b\x32(.oak9.tython.aws.glue.PartitionSerdeInfo\x12:\n\x0csort_columns\x18\x0b \x03(\x0b\x32$.oak9.tython.aws.glue.PartitionOrder\x12\x12\n\ncompressed\x18\x0c \x01(\x08\x12\x10\n\x08location\x18\r \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x02\n\x17PartitionPartitionInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Q\n\nparameters\x18\x02 \x03(\x0b\x32=.oak9.tython.aws.glue.PartitionPartitionInput.ParametersEntry\x12L\n\x12storage_descriptor\x18\x03 \x01(\x0b\x32\x30.oak9.tython.aws.glue.PartitionStorageDescriptor\x12\x0e\n\x06values\x18\x04 \x03(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcb\x01\n\tPartition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x15\n\rdatabase_name\x18\x03 \x01(\t\x12\x12\n\ncatalog_id\x18\x04 \x01(\t\x12\x46\n\x0fpartition_input\x18\x05 \x01(\x0b\x32-.oak9.tython.aws.glue.PartitionPartitionInput\"]\n\"SecurityConfigurationS3Encryptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9e\x01\n)SecurityConfigurationCloudWatchEncryption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bkms_key_arn\x18\x02 \x01(\t\x12#\n\x1b\x63loud_watch_encryption_mode\x18\x03 \x01(\t\"\xa2\x01\n+SecurityConfigurationJobBookmarksEncryption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bkms_key_arn\x18\x02 \x01(\t\x12%\n\x1djob_bookmarks_encryption_mode\x18\x03 \x01(\t\"\xff\x02\n,SecurityConfigurationEncryptionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x0es3_encryptions\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.glue.SecurityConfigurationS3Encryptions\x12_\n\x16\x63loud_watch_encryption\x18\x03 \x01(\x0b\x32?.oak9.tython.aws.glue.SecurityConfigurationCloudWatchEncryption\x12\x63\n\x18job_bookmarks_encryption\x18\x04 \x01(\x0b\x32\x41.oak9.tython.aws.glue.SecurityConfigurationJobBookmarksEncryption\"\xc4\x01\n\x15SecurityConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x64\n\x18\x65ncryption_configuration\x18\x02 \x01(\x0b\x32\x42.oak9.tython.aws.glue.SecurityConfigurationEncryptionConfiguration\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xc0\x02\n\x0fTableSkewedInfo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13skewed_column_names\x18\x02 \x03(\t\x12\x1c\n\x14skewed_column_values\x18\x03 \x03(\t\x12s\n!skewed_column_value_location_maps\x18\x04 \x03(\x0b\x32H.oak9.tython.aws.glue.TableSkewedInfo.SkewedColumnValueLocationMapsEntry\x1a\x44\n\"SkewedColumnValueLocationMapsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x0bTableColumn\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xf3\x01\n\x0eTableSerdeInfo\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12H\n\nparameters\x18\x02 \x03(\x0b\x32\x34.oak9.tython.aws.glue.TableSerdeInfo.ParametersEntry\x12\x1d\n\x15serialization_library\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"i\n\nTableOrder\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\t\x12\x12\n\nsort_order\x18\x03 \x01(\x05\"\xe1\x04\n\x16TableStorageDescriptor\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19stored_as_sub_directories\x18\x02 \x01(\x08\x12P\n\nparameters\x18\x03 \x03(\x0b\x32<.oak9.tython.aws.glue.TableStorageDescriptor.ParametersEntry\x12\x16\n\x0e\x62ucket_columns\x18\x04 \x03(\t\x12:\n\x0bskewed_info\x18\x05 \x01(\x0b\x32%.oak9.tython.aws.glue.TableSkewedInfo\x12\x14\n\x0cinput_format\x18\x06 \x01(\t\x12\x19\n\x11number_of_buckets\x18\x07 \x01(\x05\x12\x15\n\routput_format\x18\x08 \x01(\t\x12\x32\n\x07\x63olumns\x18\t \x03(\x0b\x32!.oak9.tython.aws.glue.TableColumn\x12\x38\n\nserde_info\x18\n \x01(\x0b\x32$.oak9.tython.aws.glue.TableSerdeInfo\x12\x36\n\x0csort_columns\x18\x0b \x03(\x0b\x32 .oak9.tython.aws.glue.TableOrder\x12\x12\n\ncompressed\x18\x0c \x01(\x08\x12\x10\n\x08location\x18\r \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xde\x03\n\x0fTableTableInput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x1a\n\x12view_original_text\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\ntable_type\x18\x05 \x01(\t\x12I\n\nparameters\x18\x06 \x03(\x0b\x32\x35.oak9.tython.aws.glue.TableTableInput.ParametersEntry\x12\x1a\n\x12view_expanded_text\x18\x07 \x01(\t\x12H\n\x12storage_descriptor\x18\x08 \x01(\x0b\x32,.oak9.tython.aws.glue.TableStorageDescriptor\x12\x39\n\x0epartition_keys\x18\t \x03(\x0b\x32!.oak9.tython.aws.glue.TableColumn\x12\x11\n\tretention\x18\n \x01(\x05\x12\x0c\n\x04name\x18\x0b \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa7\x01\n\x05Table\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12:\n\x0btable_input\x18\x02 \x01(\x0b\x32%.oak9.tython.aws.glue.TableTableInput\x12\x15\n\rdatabase_name\x18\x03 \x01(\t\x12\x12\n\ncatalog_id\x18\x04 \x01(\t\"r\n\x1bTriggerNotificationProperty\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12notify_delay_after\x18\x02 \x01(\x05\"\xec\x02\n\rTriggerAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12P\n\x15notification_property\x18\x02 \x01(\x0b\x32\x31.oak9.tython.aws.glue.TriggerNotificationProperty\x12\x14\n\x0c\x63rawler_name\x18\x03 \x01(\t\x12\x0f\n\x07timeout\x18\x04 \x01(\x05\x12\x10\n\x08job_name\x18\x05 \x01(\t\x12\x45\n\targuments\x18\x06 \x03(\x0b\x32\x32.oak9.tython.aws.glue.TriggerAction.ArgumentsEntry\x12\x1e\n\x16security_configuration\x18\x07 \x01(\t\x1a\x30\n\x0e\x41rgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb1\x01\n\x10TriggerCondition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63rawler_name\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\x13\n\x0b\x63rawl_state\x18\x04 \x01(\t\x12\x18\n\x10logical_operator\x18\x05 \x01(\t\x12\x10\n\x08job_name\x18\x06 \x01(\t\"\x98\x01\n\x10TriggerPredicate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07logical\x18\x02 \x01(\t\x12:\n\nconditions\x18\x03 \x03(\x0b\x32&.oak9.tython.aws.glue.TriggerCondition\"\x8c\x03\n\x07Trigger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x19\n\x11start_on_creation\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x34\n\x07\x61\x63tions\x18\x05 \x03(\x0b\x32#.oak9.tython.aws.glue.TriggerAction\x12\x15\n\rworkflow_name\x18\x06 \x01(\t\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\x35\n\x04tags\x18\x08 \x03(\x0b\x32\'.oak9.tython.aws.glue.Trigger.TagsEntry\x12\x0c\n\x04name\x18\t \x01(\t\x12\x39\n\tpredicate\x18\n \x01(\x0b\x32&.oak9.tython.aws.glue.TriggerPredicate\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe2\x02\n\x08Workflow\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12X\n\x16\x64\x65\x66\x61ult_run_properties\x18\x03 \x03(\x0b\x32\x38.oak9.tython.aws.glue.Workflow.DefaultRunPropertiesEntry\x12\x36\n\x04tags\x18\x04 \x03(\x0b\x32(.oak9.tython.aws.glue.Workflow.TagsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x1a;\n\x19\x44\x65\x66\x61ultRunPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n!SecurityConfigurationS3Encryption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bkms_key_arn\x18\x02 \x01(\t\x12\x1a\n\x12s3_encryption_mode\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_glue_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONNECTIONCONNECTIONINPUT_CONNECTIONPROPERTIESENTRY._options = None
  _CONNECTIONCONNECTIONINPUT_CONNECTIONPROPERTIESENTRY._serialized_options = b'8\001'
  _CRAWLER_TAGSENTRY._options = None
  _CRAWLER_TAGSENTRY._serialized_options = b'8\001'
  _DATABASEDATABASEINPUT_PARAMETERSENTRY._options = None
  _DATABASEDATABASEINPUT_PARAMETERSENTRY._serialized_options = b'8\001'
  _DEVENDPOINT_ARGUMENTSENTRY._options = None
  _DEVENDPOINT_ARGUMENTSENTRY._serialized_options = b'8\001'
  _DEVENDPOINT_TAGSENTRY._options = None
  _DEVENDPOINT_TAGSENTRY._serialized_options = b'8\001'
  _JOB_DEFAULTARGUMENTSENTRY._options = None
  _JOB_DEFAULTARGUMENTSENTRY._serialized_options = b'8\001'
  _JOB_TAGSENTRY._options = None
  _JOB_TAGSENTRY._serialized_options = b'8\001'
  _MLTRANSFORM_TAGSENTRY._options = None
  _MLTRANSFORM_TAGSENTRY._serialized_options = b'8\001'
  _PARTITIONSKEWEDINFO_SKEWEDCOLUMNVALUELOCATIONMAPSENTRY._options = None
  _PARTITIONSKEWEDINFO_SKEWEDCOLUMNVALUELOCATIONMAPSENTRY._serialized_options = b'8\001'
  _PARTITIONSERDEINFO_PARAMETERSENTRY._options = None
  _PARTITIONSERDEINFO_PARAMETERSENTRY._serialized_options = b'8\001'
  _PARTITIONSTORAGEDESCRIPTOR_PARAMETERSENTRY._options = None
  _PARTITIONSTORAGEDESCRIPTOR_PARAMETERSENTRY._serialized_options = b'8\001'
  _PARTITIONPARTITIONINPUT_PARAMETERSENTRY._options = None
  _PARTITIONPARTITIONINPUT_PARAMETERSENTRY._serialized_options = b'8\001'
  _TABLESKEWEDINFO_SKEWEDCOLUMNVALUELOCATIONMAPSENTRY._options = None
  _TABLESKEWEDINFO_SKEWEDCOLUMNVALUELOCATIONMAPSENTRY._serialized_options = b'8\001'
  _TABLESERDEINFO_PARAMETERSENTRY._options = None
  _TABLESERDEINFO_PARAMETERSENTRY._serialized_options = b'8\001'
  _TABLESTORAGEDESCRIPTOR_PARAMETERSENTRY._options = None
  _TABLESTORAGEDESCRIPTOR_PARAMETERSENTRY._serialized_options = b'8\001'
  _TABLETABLEINPUT_PARAMETERSENTRY._options = None
  _TABLETABLEINPUT_PARAMETERSENTRY._serialized_options = b'8\001'
  _TRIGGERACTION_ARGUMENTSENTRY._options = None
  _TRIGGERACTION_ARGUMENTSENTRY._serialized_options = b'8\001'
  _TRIGGER_TAGSENTRY._options = None
  _TRIGGER_TAGSENTRY._serialized_options = b'8\001'
  _WORKFLOW_DEFAULTRUNPROPERTIESENTRY._options = None
  _WORKFLOW_DEFAULTRUNPROPERTIESENTRY._serialized_options = b'8\001'
  _WORKFLOW_TAGSENTRY._options = None
  _WORKFLOW_TAGSENTRY._serialized_options = b'8\001'
  _CLASSIFIERXMLCLASSIFIER._serialized_start=66
  _CLASSIFIERXMLCLASSIFIER._serialized_end=203
  _CLASSIFIERJSONCLASSIFIER._serialized_start=205
  _CLASSIFIERJSONCLASSIFIER._serialized_end=321
  _CLASSIFIERCSVCLASSIFIER._serialized_start=324
  _CLASSIFIERCSVCLASSIFIER._serialized_end=563
  _CLASSIFIERGROKCLASSIFIER._serialized_start=566
  _CLASSIFIERGROKCLASSIFIER._serialized_end=734
  _CLASSIFIER._serialized_start=737
  _CLASSIFIER._serialized_end=1094
  _GLUE._serialized_start=1097
  _GLUE._serialized_end=1932
  _CONNECTIONPHYSICALCONNECTIONREQUIREMENTS._serialized_start=1935
  _CONNECTIONPHYSICALCONNECTIONREQUIREMENTS._serialized_end=2112
  _CONNECTIONCONNECTIONINPUT._serialized_start=2115
  _CONNECTIONCONNECTIONINPUT._serialized_end=2556
  _CONNECTIONCONNECTIONINPUT_CONNECTIONPROPERTIESENTRY._serialized_start=2497
  _CONNECTIONCONNECTIONINPUT_CONNECTIONPROPERTIESENTRY._serialized_end=2556
  _CONNECTION._serialized_start=2559
  _CONNECTION._serialized_end=2723
  _CRAWLERSCHEMACHANGEPOLICY._serialized_start=2726
  _CRAWLERSCHEMACHANGEPOLICY._serialized_end=2860
  _CRAWLERSCHEDULE._serialized_start=2862
  _CRAWLERSCHEDULE._serialized_end=2965
  _CRAWLERS3TARGET._serialized_start=2967
  _CRAWLERS3TARGET._serialized_end=3075
  _CRAWLERCATALOGTARGET._serialized_start=3077
  _CRAWLERCATALOGTARGET._serialized_end=3195
  _CRAWLERJDBCTARGET._serialized_start=3198
  _CRAWLERJDBCTARGET._serialized_end=3333
  _CRAWLERDYNAMODBTARGET._serialized_start=3335
  _CRAWLERDYNAMODBTARGET._serialized_end=3429
  _CRAWLERTARGETS._serialized_start=3432
  _CRAWLERTARGETS._serialized_end=3768
  _CRAWLER._serialized_start=3771
  _CRAWLER._serialized_end=4306
  _CRAWLER_TAGSENTRY._serialized_start=4263
  _CRAWLER_TAGSENTRY._serialized_end=4306
  _DATACATALOGENCRYPTIONSETTINGSCONNECTIONPASSWORDENCRYPTION._serialized_start=4309
  _DATACATALOGENCRYPTIONSETTINGSCONNECTIONPASSWORDENCRYPTION._serialized_end=4491
  _DATACATALOGENCRYPTIONSETTINGSENCRYPTIONATREST._serialized_start=4494
  _DATACATALOGENCRYPTIONSETTINGSENCRYPTIONATREST._serialized_end=4659
  _DATACATALOGENCRYPTIONSETTINGSDATACATALOGENCRYPTIONSETTINGS._serialized_start=4662
  _DATACATALOGENCRYPTIONSETTINGSDATACATALOGENCRYPTIONSETTINGS._serialized_end=4997
  _DATACATALOGENCRYPTIONSETTINGS._serialized_start=5000
  _DATACATALOGENCRYPTIONSETTINGS._serialized_end=5232
  _DATABASEDATABASEINPUT._serialized_start=5235
  _DATABASEDATABASEINPUT._serialized_end=5504
  _DATABASEDATABASEINPUT_PARAMETERSENTRY._serialized_start=5455
  _DATABASEDATABASEINPUT_PARAMETERSENTRY._serialized_end=5504
  _DATABASE._serialized_start=5507
  _DATABASE._serialized_end=5663
  _DEVENDPOINT._serialized_start=5666
  _DEVENDPOINT._serialized_end=6278
  _DEVENDPOINT_ARGUMENTSENTRY._serialized_start=6185
  _DEVENDPOINT_ARGUMENTSENTRY._serialized_end=6233
  _DEVENDPOINT_TAGSENTRY._serialized_start=4263
  _DEVENDPOINT_TAGSENTRY._serialized_end=4306
  _JOBCONNECTIONSLIST._serialized_start=6280
  _JOBCONNECTIONSLIST._serialized_end=6378
  _JOBNOTIFICATIONPROPERTY._serialized_start=6380
  _JOBNOTIFICATIONPROPERTY._serialized_end=6490
  _JOBJOBCOMMAND._serialized_start=6493
  _JOBJOBCOMMAND._serialized_end=6628
  _JOBEXECUTIONPROPERTY._serialized_start=6630
  _JOBEXECUTIONPROPERTY._serialized_end=6738
  _JOB._serialized_start=6741
  _JOB._serialized_end=7555
  _JOB_DEFAULTARGUMENTSENTRY._serialized_start=7455
  _JOB_DEFAULTARGUMENTSENTRY._serialized_end=7510
  _JOB_TAGSENTRY._serialized_start=4263
  _JOB_TAGSENTRY._serialized_end=4306
  _MLTRANSFORMFINDMATCHESPARAMETERS._serialized_start=7558
  _MLTRANSFORMFINDMATCHESPARAMETERS._serialized_end=7782
  _MLTRANSFORMTRANSFORMPARAMETERS._serialized_start=7785
  _MLTRANSFORMTRANSFORMPARAMETERS._serialized_end=7987
  _MLTRANSFORMGLUETABLES._serialized_start=7990
  _MLTRANSFORMGLUETABLES._serialized_end=8158
  _MLTRANSFORMINPUTRECORDTABLES._serialized_start=8161
  _MLTRANSFORMINPUTRECORDTABLES._serialized_end=8314
  _MLTRANSFORM._serialized_start=8317
  _MLTRANSFORM._serialized_end=8835
  _MLTRANSFORM_TAGSENTRY._serialized_start=4263
  _MLTRANSFORM_TAGSENTRY._serialized_end=4306
  _PARTITIONSKEWEDINFO._serialized_start=8838
  _PARTITIONSKEWEDINFO._serialized_end=9166
  _PARTITIONSKEWEDINFO_SKEWEDCOLUMNVALUELOCATIONMAPSENTRY._serialized_start=9098
  _PARTITIONSKEWEDINFO_SKEWEDCOLUMNVALUELOCATIONMAPSENTRY._serialized_end=9166
  _PARTITIONCOLUMN._serialized_start=9168
  _PARTITIONCOLUMN._serialized_end=9273
  _PARTITIONSERDEINFO._serialized_start=9276
  _PARTITIONSERDEINFO._serialized_end=9527
  _PARTITIONSERDEINFO_PARAMETERSENTRY._serialized_start=5455
  _PARTITIONSERDEINFO_PARAMETERSENTRY._serialized_end=5504
  _PARTITIONORDER._serialized_start=9529
  _PARTITIONORDER._serialized_end=9638
  _PARTITIONSTORAGEDESCRIPTOR._serialized_start=9641
  _PARTITIONSTORAGEDESCRIPTOR._serialized_end=10274
  _PARTITIONSTORAGEDESCRIPTOR_PARAMETERSENTRY._serialized_start=5455
  _PARTITIONSTORAGEDESCRIPTOR_PARAMETERSENTRY._serialized_end=5504
  _PARTITIONPARTITIONINPUT._serialized_start=10277
  _PARTITIONPARTITIONINPUT._serialized_end=10587
  _PARTITIONPARTITIONINPUT_PARAMETERSENTRY._serialized_start=5455
  _PARTITIONPARTITIONINPUT_PARAMETERSENTRY._serialized_end=5504
  _PARTITION._serialized_start=10590
  _PARTITION._serialized_end=10793
  _SECURITYCONFIGURATIONS3ENCRYPTIONS._serialized_start=10795
  _SECURITYCONFIGURATIONS3ENCRYPTIONS._serialized_end=10888
  _SECURITYCONFIGURATIONCLOUDWATCHENCRYPTION._serialized_start=10891
  _SECURITYCONFIGURATIONCLOUDWATCHENCRYPTION._serialized_end=11049
  _SECURITYCONFIGURATIONJOBBOOKMARKSENCRYPTION._serialized_start=11052
  _SECURITYCONFIGURATIONJOBBOOKMARKSENCRYPTION._serialized_end=11214
  _SECURITYCONFIGURATIONENCRYPTIONCONFIGURATION._serialized_start=11217
  _SECURITYCONFIGURATIONENCRYPTIONCONFIGURATION._serialized_end=11600
  _SECURITYCONFIGURATION._serialized_start=11603
  _SECURITYCONFIGURATION._serialized_end=11799
  _TABLESKEWEDINFO._serialized_start=11802
  _TABLESKEWEDINFO._serialized_end=12122
  _TABLESKEWEDINFO_SKEWEDCOLUMNVALUELOCATIONMAPSENTRY._serialized_start=9098
  _TABLESKEWEDINFO_SKEWEDCOLUMNVALUELOCATIONMAPSENTRY._serialized_end=9166
  _TABLECOLUMN._serialized_start=12124
  _TABLECOLUMN._serialized_end=12225
  _TABLESERDEINFO._serialized_start=12228
  _TABLESERDEINFO._serialized_end=12471
  _TABLESERDEINFO_PARAMETERSENTRY._serialized_start=5455
  _TABLESERDEINFO_PARAMETERSENTRY._serialized_end=5504
  _TABLEORDER._serialized_start=12473
  _TABLEORDER._serialized_end=12578
  _TABLESTORAGEDESCRIPTOR._serialized_start=12581
  _TABLESTORAGEDESCRIPTOR._serialized_end=13190
  _TABLESTORAGEDESCRIPTOR_PARAMETERSENTRY._serialized_start=5455
  _TABLESTORAGEDESCRIPTOR_PARAMETERSENTRY._serialized_end=5504
  _TABLETABLEINPUT._serialized_start=13193
  _TABLETABLEINPUT._serialized_end=13671
  _TABLETABLEINPUT_PARAMETERSENTRY._serialized_start=5455
  _TABLETABLEINPUT_PARAMETERSENTRY._serialized_end=5504
  _TABLE._serialized_start=13674
  _TABLE._serialized_end=13841
  _TRIGGERNOTIFICATIONPROPERTY._serialized_start=13843
  _TRIGGERNOTIFICATIONPROPERTY._serialized_end=13957
  _TRIGGERACTION._serialized_start=13960
  _TRIGGERACTION._serialized_end=14324
  _TRIGGERACTION_ARGUMENTSENTRY._serialized_start=6185
  _TRIGGERACTION_ARGUMENTSENTRY._serialized_end=6233
  _TRIGGERCONDITION._serialized_start=14327
  _TRIGGERCONDITION._serialized_end=14504
  _TRIGGERPREDICATE._serialized_start=14507
  _TRIGGERPREDICATE._serialized_end=14659
  _TRIGGER._serialized_start=14662
  _TRIGGER._serialized_end=15058
  _TRIGGER_TAGSENTRY._serialized_start=4263
  _TRIGGER_TAGSENTRY._serialized_end=4306
  _WORKFLOW._serialized_start=15061
  _WORKFLOW._serialized_end=15415
  _WORKFLOW_DEFAULTRUNPROPERTIESENTRY._serialized_start=15311
  _WORKFLOW_DEFAULTRUNPROPERTIESENTRY._serialized_end=15370
  _WORKFLOW_TAGSENTRY._serialized_start=4263
  _WORKFLOW_TAGSENTRY._serialized_end=4306
  _SECURITYCONFIGURATIONS3ENCRYPTION._serialized_start=15418
  _SECURITYCONFIGURATIONS3ENCRYPTION._serialized_end=15559
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class NotificationRuleTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_TYPE_FIELD_NUMBER: builtins.int
    TARGET_ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    target_type: builtins.str
    target_address: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target_type: builtins.str = ...,
        target_address: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target_address", b"target_address", "target_type", b"target_type"]) -> None: ...

global___NotificationRuleTarget = NotificationRuleTarget

@typing_extensions.final
class NotificationRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EVENT_TYPE_IDS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DETAIL_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def event_type_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    status: builtins.str
    detail_type: builtins.str
    resource: builtins.str
    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotificationRuleTarget]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        event_type_ids: collections.abc.Iterable[builtins.str] | None = ...,
        status: builtins.str = ...,
        detail_type: builtins.str = ...,
        resource: builtins.str = ...,
        targets: collections.abc.Iterable[global___NotificationRuleTarget] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["detail_type", b"detail_type", "event_type_ids", b"event_type_ids", "name", b"name", "resource", b"resource", "resource_info", b"resource_info", "status", b"status", "tags", b"tags", "targets", b"targets"]) -> None: ...

global___NotificationRule = NotificationRule

@typing_extensions.final
class CodeStarNotifications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_RULE_FIELD_NUMBER: builtins.int
    @property
    def notification_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NotificationRule]: ...
    def __init__(
        self,
        *,
        notification_rule: collections.abc.Iterable[global___NotificationRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_rule", b"notification_rule"]) -> None: ...

global___CodeStarNotifications = CodeStarNotifications



# Copyright 2017-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may
# not use this file except in compliance with the License. A copy of the License is located at
#
#        http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.

print('No docstring at the module level')